diff --git a/src/backend/access/transam/xlog.c b/src/backend/access/transam/xlog.c
index 150d56a..e0fd7a2 100644
--- a/src/backend/access/transam/xlog.c
+++ b/src/backend/access/transam/xlog.c
@@ -76,8 +76,6 @@ extern uint32 bootstrap_data_checksum_version;
 /* File path names (all relative to $PGDATA) */
 #define RECOVERY_COMMAND_FILE	"recovery.conf"
 #define RECOVERY_COMMAND_DONE	"recovery.done"
-#define PROMOTE_SIGNAL_FILE		"promote"
-#define FALLBACK_PROMOTE_SIGNAL_FILE "fallback_promote"
 
 
 /* User-settable parameters */
@@ -835,6 +833,7 @@ static void WriteControlFile(void);
 static void ReadControlFile(void);
 static char *str_time(pg_time_t tnow);
 static bool CheckForStandbyTrigger(void);
+static void RemoveStandbyTrigger(void);
 
 #ifdef WAL_DEBUG
 static void xlog_outrec(StringInfo buf, XLogReaderState *record);
@@ -5965,6 +5964,11 @@ StartupXLOG(void)
 		recoveryTargetTLI = ControlFile->checkPointCopy.ThisTimeLineID;
 
 	/*
+	 * Remove any trigger file present and remove them.
+	 */
+	RemoveStandbyTrigger();
+
+	/*
 	 * Check for recovery control file, and if so set up state for offline
 	 * recovery
 	 */
@@ -11545,6 +11549,21 @@ CheckForStandbyTrigger(void)
 }
 
 /*
+ * Remove any trigger file able to trigger promotion. This should be
+ * called at the beginning of recovery.
+ */
+static void
+RemoveStandbyTrigger(void)
+{
+	struct stat stat_buf;
+
+	if (stat(PROMOTE_SIGNAL_FILE, &stat_buf) == 0)
+		unlink(PROMOTE_SIGNAL_FILE);
+	if (stat(FALLBACK_PROMOTE_SIGNAL_FILE, &stat_buf) == 0)
+		unlink(FALLBACK_PROMOTE_SIGNAL_FILE);
+}
+
+/*
  * Check to see if a promote request has arrived. Should be
  * called by postmaster after receiving SIGUSR1.
  */
diff --git a/src/backend/replication/basebackup.c b/src/backend/replication/basebackup.c
index 1e86e4c..b3d0498 100644
--- a/src/backend/replication/basebackup.c
+++ b/src/backend/replication/basebackup.c
@@ -911,6 +911,15 @@ sendDir(char *path, int basepathlen, bool sizeonly, List *tablespaces,
 			continue;
 
 		/*
+		 * Skip promote signal files. Those files may have been created by
+		 * pg_ctl to trigger a promotion but they do not belong to a base
+		 * backup.
+		 */
+		if (strcmp(de->d_name, PROMOTE_SIGNAL_FILE) == 0 ||
+			strcmp(de->d_name, FALLBACK_PROMOTE_SIGNAL_FILE) == 0)
+			continue;
+
+		/*
 		 * Check if the postmaster has signaled us to exit, and abort with an
 		 * error in that case. The error handler further up will call
 		 * do_pg_abort_backup() for us. Also check that if the backup was
diff --git a/src/include/access/xlog_internal.h b/src/include/access/xlog_internal.h
index fbf9324..9de8d75 100644
--- a/src/include/access/xlog_internal.h
+++ b/src/include/access/xlog_internal.h
@@ -132,6 +132,12 @@ typedef XLogLongPageHeaderData *XLogLongPageHeader;
 #define XLOG_CONTROL_FILE	"global/pg_control"
 
 /*
+ * Promote signal files (relative to $PGDATA)
+ */
+#define PROMOTE_SIGNAL_FILE				"promote"
+#define FALLBACK_PROMOTE_SIGNAL_FILE	"fallback_promote"
+
+/*
  * These macros encapsulate knowledge about the exact layout of XLog file
  * names, timeline history file names, and archive-status file names.
  */
